@@ -498,6 +498,11 @@ virgl_renderer_submit_cmd2(void *buffer,
                            uint64_t *in_fence_ids,
                            uint32_t num_in_fences);
 
+/* vtest semi-private APIs: */
+VIRGL_EXPORT int virgl_renderer_attach_fence(int ctx_id, int fence_fd);
+VIRGL_EXPORT int virgl_renderer_get_fence_fd(uint64_t fence_id);
+VIRGL_EXPORT int virgl_renderer_get_dev_fd(int ctx_id);
+
 #endif /* VIRGL_RENDERER_UNSTABLE_APIS */
 
 #endif
